import React, {Component} from 'react'
import './bargain-middle-page.scss'
import classnames from 'classnames'
import {HeaderBar, VList} from '@common'
import {Course} from '@common'
import {api, getParam, http} from "@/utils"
import {Toast} from "antd-mobile"
import {Link, withRouter} from "react-router-dom"
import Ranking from './ranking'
import {getHours, getMinutes, getSeconds} from "date-fns"
import Overlay from '../detail/overlay'
import {compose} from "redux"


class BargainMiddlePage extends Component {

    constructor(props) {
        super(props)
        this.state = {
            isShowOverlay: false,
            isOriginator: getParam('is_originator'),
            kanjiaIcon: require('./image/kanjia_icon.png'),
            courseList: '',  // 所有砍价课程
            data: '',
            bargainData: '',
            limitPeople: 0,
            outList: [],
            list: [],
            width: '0',
            isShowMore: '',
            status: ''
        }
    }

    componentDidMount() {
        this.getBargainRankList('144', 1)
        this.getBargainCourse()
        this.getBargainInfo()
    }

    // 获取砍价信息
    getBargainInfo = () => {
        http.get(`${api.home}/m/bargain/info?bargaincode=3133332c343739343131&is_originator=1`).then((res) => {
            if (res.data.code === 200) {
                this.setState({
                    data: res.data.data,
                    originatorUid: res.data.data.originator_uid,
                    limitPeople: res.data.data.course.limit_people,
                    bargainData: res.data.data.bargain,
                    width: (res.data.data.bargain.bargain_price / res.data.data.bargain.total_price).toFixed(2) * 100 + '%'
                })
            } else {
                Toast.info(res.data.msg, 2)
            }
        })
    }

    // 获取砍价课程
    getBargainCourse = () => {
        http.get(`${api.home}/m/bargain/courseList`).then((res) => {
            if (res.data.code === 200) {
                this.setState({
                    courseList: res.data.data
                })
            } else {
                Toast.info(res.data.msg, 2)
            }
        })
    }

    // 获取助理好友
    getBargainRankList = (id, type) => {
        let data = {
            courseId: id,
            type: type
        }
        http.post(`${api.home}/m/bargain/rankList`, data).then((res) => {
            if (res.data.code === 200) {
                let arr = ['刀神', '刀王', '刀霸']
                let newList = res.data.data.out_list.map((item, i) => {
                    return {
                        ...item,
                        rank: arr[i]
                    }
                })
                this.setState({
                    list: res.data.data.list,
                    outList: newList
                })
            } else {
                Toast.info(res.data.msg, 2)
            }
        })
    }

    // 加入购物车
    toCart = () => {
        let data = {
            course_id: getParam('id')
        }
        http.post(`${api.home}/m/cart/add`, data).then((res) => {
            if (res.data.code === 200 || res.data.code === 15001) {
                this.props.history.push('/shopcart')
            } else {
                Toast.info(res.data.msg, 2);
            }
        })
    }

    // 查看更多
    getMore = () => {
        this.setState({
            isShowMore: true
        })
    }
    // 自组件传给父组件的boxHide
    boxHide = (val) => {
        this.setState({isShowMore: val})
    }

    // 领取砍价神器
    toArtifact = () => {
        let data = {
            courseId: getParam('id')
        }
        http.post(`${api.home}/m/bargain/receiveLimit`, data).then((res) => {
            if (res.data.code === 200) {
                this.setState({
                    isShowOverlay: true,
                    status: 5,
                })
            } else {
                Toast.info(res.data.msg, 2)
            }
        })
    }

    // 使用砍价神器
    useArtifact = () => {
        this.toKanjia(getParam('id'), 2, 0)
    }

    // 砍价接口
    toKanjia = (id, type, uid) => {
        let data = {
            course_id: id,
            type: type,  // 1 用户自己砍价 2 使用砍价神器 3 好友助力砍价 4 好友第二次助力
            parent_uid: uid // 被助力人id 【自己本人操作传0】
        }
        http.post(`${api.home}/m/to_bargain`, data).then((res) => {
            if (res.data.code === 200) {
                this.getBargainInfo()
                if (type === 2) {
                    this.setState({
                        isShowOverlay: true,
                        status: 6
                    })
                }
                if (type === 3) {
                    this.userStatus()
                }
                if (type === 4) {
                    this.setState({
                        isShowOverlay: true,
                        status: 3
                    })
                }

                // this.setState({
                //     isShowOverlay: true,
                //     status: 4
                // })

            } else {
                Toast.info(res.data.msg, 2)
            }
        })
    }

    // 获取用户状态
    userStatus = () => {
        http.get(`${api.home}/sys/userStatus`).then((res) => {
            if (res.data.code === 200) {
                //  0-都没绑定 1-只绑定公众号 2-只绑定手机号 3-都绑定
                if (res.data.data.status === 0 || res.data.data.status === 2) {
                    this.setState({
                        isShowOverlay: true,
                        status: 1
                    })
                } else {
                    this.setState({
                        isShowOverlay: true,
                        status: 2
                    })
                }
            } else {
                Toast.info(res.data.msg, 2)
            }
        })
    }


    // 帮好友砍价第一刀
    friendBargainFirst = () => {
        this.toKanjia(getParam('id'), 3, this.state.originatorUid)
    }

    // 帮好友砍价第二刀
    friendBargainSecond = () => {
        this.toKanjia(getParam('id'), 4, this.state.originatorUid)
    }


    // 关闭弹窗
    close = () => {
        this.setState({
            isShowOverlay: false,
            status: '',
        })
    }

    render() {
        let date, h, m, s
        if (this.state.bargainData.expire_time) {
            date = new Date(this.state.bargainData.expire_time * 1000)
            h = <span className={'time hour'}>{getHours(date)}</span>
            m = <span className={'time hour'}>{getMinutes(date)}</span>
            s = <span className={'time hour'}>{getSeconds(date)}</span>
        }

        let thirdRow, btn
        // is_artifact	 0-再邀请多少人可以使用 1-可以使用未领取 2-已领取 3-已使用
        if (this.state.bargainData.is_artifact === 0) {
            thirdRow =
                <div>再邀请<span className={'indicator'}>{this.state.bargainData.invite_num}</span>位好友助力即可获得<span
                    className={'indicator'}>【砍价神器】</span></div>
        } else if (this.state.bargainData.is_artifact === 1) {
            thirdRow = <div>恭喜你获得<span className={'indicator'}>【砍价神器】</span></div>
            btn = <button onClick={this.toArtifact}>立即领取</button>
        } else if (this.state.bargainData.is_artifact === 2) {
            thirdRow = <div>恭喜你获得<span className={'indicator'}>【砍价神器】</span></div>
            btn = <button onClick={this.useArtifact}>立即使用</button>
        }


        let bargainBtn
        if (this.state.isOriginator === '2' && this.state.data.assist_status === 0) {
            bargainBtn = <button onClick={this.friendBargainFirst}>帮好友砍一刀</button>
        } else if (this.state.isOriginator === '2' && this.state.data.assist_status === 1) {
            bargainBtn = <button onClick={this.friendBargainSecond}>再砍一刀</button>
        } else if (this.state.isOriginator === '2' && this.state.data.assist_status === 2) {
            bargainBtn = <button className={'invalid-btn'}>已帮好友助力</button>
        } else if (this.state.data.bargain_status === 1 || this.state.data.bargain_status === 2) {
            bargainBtn = <button className={'invalid-btn'}>砍价结束</button>
        } else if (this.state.isOriginator === '1' && this.state.data.bargain_status === 0) {
            bargainBtn = <button>邀请好友砍价</button>
        }


        return (
            <div className={'bargain-middle-page'}>
                <HeaderBar title='砍价详情' arrow={true} cart={true}></HeaderBar>
                <div className="top">
                    <div className="bargain-area">
                        {
                            this.state.isOriginator === '2' &&
                            <p className='bargain-tip'>你的好友发现一门精品课程，快来一起帮他砍价：</p>
                        }

                        <ul>
                            <VList
                                info={<CourseDes data={this.state.data} toCart={this.toCart}/>}
                            />
                        </ul>
                        <div className="bargain-detail">
                            <div className="top">
                                <div>
                                    已砍<span className={'reduced-price'}>{this.state.bargainData.bargain_price}元</span>
                                </div>
                                {
                                    this.state.data.bargain_status === 0 &&
                                    <div>
                                        {h} : {m} : {s}
                                        <span className={'inactive'}> 后砍价结束</span>
                                    </div>
                                }

                            </div>
                            <div className="middle">
                                <span style={{width: this.state.width}}></span>
                            </div>
                            {
                                this.state.isOriginator === '1' && this.state.data.bargain_status === 0 &&
                                <div>
                                    {thirdRow}
                                    {btn}
                                </div>
                            }
                            <div className={'button'}>
                                {bargainBtn}
                            </div>

                        </div>
                    </div>
                    <div className="bargain-records">
                        <div className="title">砍价记录</div>
                        <ul>
                            {
                                this.state.outList && this.state.outList.length > 0 && this.state.outList.map((item, index) => {
                                    return (
                                        <li key={index}>
                                            <div className="left">
                                                <img className='avatar' src={item.avatar_file} alt=""/>
                                                <span className={'nickname'}>{item.user_name}</span>
                                                <span className="rank-tag">{item.rank}</span>
                                            </div>
                                            <div className="right">
                                                <img className='kanjia-icon' src={this.state.kanjiaIcon} alt=""/>
                                                砍掉<span className={'price'}>{item.amount}</span>
                                            </div>
                                        </li>
                                    )
                                })

                            }

                        </ul>
                        <div className="more" onClick={this.getMore}>查看更多>></div>
                    </div>
                </div>
                <div className="bargain-course-list">
                    <div className="title-wrapper">
                        <div className="title">我要砍价</div>
                        <div className="subtitle">邀请{this.state.limitPeople}位以上好友帮忙砍价可获得【砍价神器】</div>
                    </div>
                    <ul>
                        {
                            this.state.courseList && this.state.courseList.length > 0 && this.state.courseList.map((item, index) => {
                                return <Course
                                    className={'text-overflow-2'}
                                    key={index}
                                    id={item.course_id}
                                    img={item.image_name}
                                    title={item.course_title}
                                    bottom={<CourseBottom
                                        item={item}
                                        toCart={this.toCart}
                                    />
                                    }
                                />
                            })
                        }
                    </ul>
                </div>
                <Link to={'/preferential'} className={'preferential'}>查看更多精品课程 >></Link>


                {/*更多好友砍价*/}
                <Ranking list={this.state.list} icon={this.state.kanjiaIcon} limitPeople={this.state.limitPeople}
                         isShowMore={this.state.isShowMore} boxHide={this.boxHide}></Ranking>


                {
                    this.state.isShowOverlay &&
                    <Overlay>

                        {/*引导关注公众号*/}
                        {
                            this.state.status === 1 &&
                            <PublicNumber/>
                        }

                        {/*好友成功砍第一刀*/}
                        {
                            this.state.status === 2 &&
                            <BargainFirst bargainSecond={this.friendBargainSecond}/>
                        }
                        {/*好友成功砍第二刀*/}
                        {
                            this.state.status === 3 &&
                            <BargainSecond/>
                        }
                        {/*不能在砍了*/}
                        {
                            this.state.status === 4 &&
                            <NotBargain/>
                        }
                        {/*领取砍价神器*/}
                        {
                            this.state.status === 5 &&
                            <Artifact useArtifact={this.useArtifact}/>
                        }
                        {/*使用砍价神器*/}
                        {
                            this.state.status === 6 &&
                            <UseArtifact toCart={this.toCart}/>
                        }


                        {
                            this.state.status !== 0 &&
                            <i onClick={this.close} className={'iconfont iconiconfront-2 bargain-close'}></i>
                        }
                    </Overlay>

                }

            </div>
        );
    }
}

function CourseDes(props) {
    const data = props.data && props.data.course
    return (
        <div className={'des'}>
            <div className="course-title text-overflow-2">
                {data.course_title}
            </div>
            <div className="price-bar">
                <span className={'discount-price'}>￥{data.pay_price}</span>
                <span className={'original-price'}>￥{data.course_price}</span>
                <button className={'purchase-btn'}
                        onClick={props.toCart}>¥{data.pay_price}去支付
                </button>
            </div>
        </div>
    )
}

function CourseBottom(props) {
    let Buttons
    if (props.item.bargain_status === 0) {
        Buttons = <button className={'bargain'}>我要砍价</button>
    } else if (props.item.bargain_status === 3) {
        Buttons = <button className={'bargain'}>去学习</button>
    } else {
        Buttons = (
            <div className="btns">
                <button className={classnames('bargain-btn', {
                    invalid: props.item.bargain_status === 2
                })}>{props.item.bargain_status === 2 ? '砍价结束' : '继续砍价'}</button>
                <button onClick={props.toCart}
                        className={'purchase-btn'}>¥{props.item.pay_price}去支付
                </button>
            </div>
        )
    }
    return (
        <div className="course-bottom">
            <div className={'course-price'}>
                <span className={'discount-price'}>¥{props.item.price1}</span>
                <span className={'original-price'}>¥{props.item.price0}</span>
            </div>
            {Buttons}
        </div>
    )
}


function PublicNumber() {
    return (
        <div className='bargain-public-number'>
            <img className='avait' src="https://julyedu-cdn.oss-cn-beijing.aliyuncs.com/tinypng-common/right_weixin.png"
                 alt=""/>
            <p className='status-title ff4'>谢谢你帮我砍了5.6元！</p>
            <p className='status-dec'>关注公众号，可以再砍一刀哦~</p>
            <img className='public-number-img'
                 src="https://julyedu-cdn.oss-cn-beijing.aliyuncs.com/tinypng-common/right_weixin.png" alt=""/>
        </div>
    )
}

function BargainFirst(props) {
    return (
        <div className='bargain-first'>
            <img className='top-img' src={require('./image/kanjia_cg_icon.png')} alt=""/>
            <p className='status-title'>谢谢你帮我砍了<span className='ff4'>5.6元</span>！</p>
            <p className='status-dec'>你还可以帮我再砍一刀哦~</p>
            <button onClick={props.bargainSecond}>再砍一刀</button>
        </div>
    )
}

function BargainSecond() {
    return (
        <div className='bargain-second'>
            <img className='top-img' src={require('./image/kanjia_cg_icon.png')} alt=""/>
            <p className='status-title'>厉害了，又帮好友砍掉<span className='ff4'>5.6元</span>！</p>
            <button>我也要砍价</button>
        </div>
    )
}

function NotBargain() {
    return (
        <div className='not-bargain'>
            <img className='middle-img' src={require('./image/kanjia_no_iccon.png')} alt=""/>
            <p className='status-title'>你的好友用【砍价神器】把我砍蒙圈了<br/>不能再砍了哦~</p>
            <p className='status-dec'>邀请20位以上好友帮忙砍价可获得【砍价神器】</p>
            <button>我也要砍价</button>
        </div>
    )
}


{/*领取砍价神器*/
}

function Artifact(props) {
    return (
        <div className='artifact-box'>
            <p className='top-tip'>恭喜你获得【砍价神器】！</p>
            <p className='middle-tip'>
                您可以使用
                <span className={'indicator'}>【砍价神器】</span>
                再砍一刀
            </p>
            <button className='use-artifact' onClick={props.useArtifact}>立即使用</button>
        </div>
    )
}

function UseArtifact(props) {
    return (
        <div className='use-artifact-box'>
            <img className='top-img' src={require('./image/kanjia_cg_icon.png')} alt=""/>
            <p className='top-tip'>厉害了，又砍掉了10元！</p>
            <p className='middle-tip'>
                你已经砍了
                <span className={'indicator'}>109元</span>
                没见过你这么能砍的人...
            </p>
            <p className='btm-tip'>
                不能再砍了哦~
            </p>
            <button className='tubuy' onClick={props.toCart}>去支付</button>
        </div>
    )
}


export default compose(
    withRouter
)(BargainMiddlePage)
